import { FC, useEffect, useState } from 'react';
import { FormFieldProps } from 'mystique/registry/FieldRegistry';
import {
  Checkbox,
  FormControl,
  FormControlLabel,
  FormHelperText,
} from '@material-ui/core';

const BooleanSelector: FC<FormFieldProps<any>> = (props) => {
  const [checked, setChecked] = useState<boolean>(
    props.extensions?.checked || props.value || false,
  );

  useEffect(() => {
    props.onChange(`${checked}`);
  }, [checked]);

  const handleChange = (event: any) => {
    setChecked(event.target.checked as boolean);
  };

  const handleOnBlur = () => {
    props && props.onBlur && props.onBlur();
  };

  return (
    <FormControl fullWidth error={!!props.error}>
      <FormControlLabel
        control={
          <Checkbox
            id="checkbox-selector"
            onChange={handleChange}
            onBlur={handleOnBlur}
            checked={checked}
          />
        }
        label={props.label}
      />
      {props.error && <FormHelperText>{props.error}</FormHelperText>}
    </FormControl>
  );
};

export default BooleanSelector;
