import { FC, useEffect, useState } from 'react';
import { FormFieldProps } from 'mystique/registry/FieldRegistry';
import { getSettings } from 'mystique/hooks/getSettings';
import { FormControl, FormHelperText, InputLabel, MenuItem, Select } from '@material-ui/core';
import { useAuth } from 'mystique/hooks/useAuth';

const SettingBaseStringSelector: FC<FormFieldProps<any>> = (props) => {
  const auth = useAuth();

  const settingName = props.extensions?.settingName;
  const [items, setItems] = useState<string[]>([]);
  const [currentItem, setCurrentItem] = useState<string | undefined>(
    props.value,
  );

  useEffect(() => {
    if (settingName) {
      getSettings(
        { setting: settingName },
        parseInt(auth.context.current.contextId),
      ).then((value) => {
        if (value.setting.status == 'ok') {
          const list: string[] = [...value.setting.result.value];
          if (props.value && !list.includes(props.value)) {
            list.push(props.value);
          }
          setItems(list);
        }
      });
    } else {
      setItems([]);
    }
  }, [settingName]);

  useEffect(() => {
    if (currentItem) {
      props.onChange(currentItem);
    } else {
      props.onChange(undefined);
    }
  }, [currentItem]);

  const handleChange = (event: any) => {
    setCurrentItem(event.target.value as string);
  };

  const handleOnBlur = () => {
    props && props.onBlur && props.onBlur();
  };

  return (
    <FormControl fullWidth error={!!props.error}>
      <InputLabel id="string-select-label">{props.label}</InputLabel>
      <Select
        labelId="string-select-label"
        id="string-select"
        label={props.label}
        onChange={handleChange}
        onBlur={handleOnBlur}
        value={currentItem}
      >
        {items.map((value, idx) => {
          return (
            <MenuItem key={idx} value={value} selected={currentItem === value}>
              {value}
            </MenuItem>
          );
        })}
      </Select>
      {props.error && <FormHelperText>{props.error}</FormHelperText>}
    </FormControl>
  );
};

export default SettingBaseStringSelector;
